@@ -23,16 +23,16 @@ from aliyunsdkimagerecog.endpoint import endpoint_data
 class DetectImageElementsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'imagerecog', '2019-09-30', 'DetectImageElements','imagerecog')
+		RpcRequest.__init__(self, 'imagerecog', '2019-09-30', 'DetectImageElements')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Url(self):
+	def get_Url(self): # String
 		return self.get_body_params().get('Url')
 
-	def set_Url(self,Url):
-		self.add_body_params('Url', Url)
\ No newline at end of file
+	def set_Url(self, Url):  # String
+		self.add_body_params('Url', Url)
